@@ -15,7 +15,7 @@ from starlette.routing import Route
 from starlette.exceptions import HTTPException
 from starlette.middleware import Middleware
 from starlette.middleware.base import BaseHTTPMiddleware
-from grpc.experimental.aio import insecure_channel
+from grpc.experimental.aio import insecure_channel, AioRpcError
 import os
 from google.protobuf import symbol_database
 from hypercorn.config import Config
@@ -104,14 +104,14 @@ def get_http_handlers(descriptor: FileDescriptor, service_name: str, method: str
       raw_output = await process_grpc_request(descriptor, service_name, method, input, channel)
       output = MessageToDict(raw_output, preserving_proto_field_name=True)
       return JSONResponse(output)
+    except AioRpcError as ex:
+      detail = ex.details()
+      grpc_status = ex.code()
+      http_status_code = status_map[grpc_status]
+      raise HTTPException(http_status_code, detail=detail)
     except Exception as ex:
-      if hasattr(ex, '_state'):
-        detail = ex._state.details
-        grpc_status = ex._state.code.name
-        http_status_code = status_map[StatusCode[grpc_status]]
-      else:
-        detail = str(ex).replace('\n', ' ')
-        http_status_code = 500
+      detail = str(ex).replace('\n', ' ')
+      http_status_code = 500
       raise HTTPException(http_status_code, detail=detail)
 
   return method_get_handler, request_handler
